-- This file is part of the YateAdmin Project http://yateadmin.null.ro
-- A free web interface to set up a server based on the Yate telephony engine.
-- Copyright (C) 2006 Null Team
--
-- Yet Another Telephony Engine - a fully featured software PBX and IVR
--
-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.

--
-- PostgreSQL database dump
--

SET client_encoding = 'LATIN1';
SET check_function_bodies = false;
SET client_min_messages = warning;

--
-- Name: SCHEMA public; Type: COMMENT; Schema: -; Owner: postgres
--

COMMENT ON SCHEMA public IS 'Standard public schema';


SET search_path = public, pg_catalog;

--
-- Name: plpgsql_call_handler(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION plpgsql_call_handler() RETURNS language_handler
    AS '$libdir/plpgsql', 'plpgsql_call_handler'
    LANGUAGE c;


ALTER FUNCTION public.plpgsql_call_handler() OWNER TO postgres;

--
-- Name: plpgsql_validator(oid); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION plpgsql_validator(oid) RETURNS void
    AS '$libdir/plpgsql', 'plpgsql_validator'
    LANGUAGE c;


ALTER FUNCTION public.plpgsql_validator(oid) OWNER TO postgres;

--
-- Name: plpgsql; Type: PROCEDURAL LANGUAGE; Schema: public; Owner:
--

CREATE TRUSTED PROCEDURAL LANGUAGE plpgsql HANDLER plpgsql_call_handler VALIDATOR plpgsql_validator;


--
-- Name: getroute(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION getroute(text) RETURNS SETOF record
    AS $_$
	DECLARE
		callednr ALIAS FOR $1;
		result record;
		partial record;
		iteration int2;
		newcalled text;
		loc record;
		dig text;
		locate text;
		flag text;
		locat text;
	BEGIN
		FOR loc IN SELECT * FROM form LIMIT 1 LOOP
			SELECT into locate line FROM lines WHERE line=callednr;
			IF FOUND THEN
				SELECT into locat location FROM lines WHERE line=callednr;
				IF FOUND AND locat IS NOT NULL THEN
					loc.location:=locat;
					loc.called:=callednr;
					RETURN next loc;
				END IF;
			END IF;
		END LOOP;
		SELECT INTO dig prefix FROM routes WHERE prefix=substr(callednr,1,LENGTH(prefix)) ORDER BY length(prefix) DESC LIMIT 1;
		IF NOT FOUND THEN
			loc.location:='';
			loc.error:='unknown prefix';
			RETURN next loc;
			RETURN;
		END IF;
		iteration:=0;
		FOR result IN SELECT * FROM form LIMIT 3 LOOP
			SELECT INTO partial * FROM routes WHERE prefix=dig OR prefix='' ORDER BY priority LIMIT 1 OFFSET iteration;
			IF NOT FOUND THEN
				IF iteration=0 THEN
					result.error:='no route to call';
					result.called:=callednr;
					RETURN next result;
				END IF;
				RETURN;
			END IF;
			newcalled := rewritenr(callednr,partial.cutbool,partial.nrdigcut,partial.poscut,partial.replacebool,partial.posrpl,partial.digrpl,partial.nrdigrpl);
			iteration:=iteration+1;
			IF partial.account IS NOT NULL AND partial.account!='' AND partial.protocol<>'zap' AND partial.protocol<>'wp' THEN
				result.location:= partial.protocol || '/' || newcalled;
				result.line:=partial.account;
			ELSEIF partial.protocol='sip' THEN
				IF partial.port IS NOT NULL OR partial.port='' THEN
					result.location := 'sip/sip:' || newcalled || '@' || partial.ip;
				ELSE
					result.location := 'sip/sip:' || newcalled || '@' || partial.ip || ':' || partial.port;
				END IF;
			ELSEIF partial.protocol='h323' THEN
				IF partial.port IS NULL OR partial.port='' THEN
					result.location := 'h323/' || newcalled || '@' || partial.ip;
				ELSE
					result.location := 'h323/' || newcalled || '@' || partial.ip || ':' || partial.port;
				END IF;
			ELSEIF partial.protocol='wp' OR partial.protocol='zap' THEN
				result.location := partial.protocol || '/' || partial.chan_group || '/' || newcalled;
			ELSEIF partial.protocol='iax' THEN
				IF partial.iaxcontext IS NULL OR partial.iaxcontext='' THEN
					IF partial.port IS NULL OR partial.port='' THEN
						result.location := 'iax/' || partial.iaxuser || '@' partial.ip || '/' || newcalled;
					ELSE
						result.location := 'iax/' || partial.iaxuser || '@' || partial.ip || ':' || partial.port || '/' || newcalled;
					END IF;
				ELSE
					IF partial.port IS NULL OR partial.port='' THEN
						result.location := 'iax/' || partial.iaxuser || '@' || partial.ip || '/' || newcalled || '@' || partial.iaxcontext;
					ELSE
						result.location := 'iax/' || partial.iaxuser || '@' || partial.ip || ':' || partial.port || '/' || newcalled || '@' || partial.iaxcontext;
					END IF;
				END IF;
			END IF;
			result.called:=newcalled;
			RETURN next result;
		END LOOP;
		RETURN;
	END;
$_$
    LANGUAGE plpgsql;


ALTER FUNCTION public.getroute(text) OWNER TO postgres;

--
-- Name: initaccounts(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION initaccounts() RETURNS SETOF record
    AS $$
	DECLARE
		result record;
	BEGIN
		FOR result IN SELECT enabled ,protocol,username, description,interval,formats,authname ,password ,server ,
gatekeeper,domain,registrar,outbound ,localaddress, modified, account ,id,status,number,TRUE AS gw FROM accounts WHERE enabled IS TRUE AND account IS NOT NULL AND username IS NOT NULL ORDER BY account LOOP
			RETURN next result;
		END LOOP;
		RETURN;
	END;
$$
    LANGUAGE plpgsql;


ALTER FUNCTION public.initaccounts() OWNER TO postgres;

--
-- Name: rewritenr(text, boolean, smallint, smallint, boolean, smallint, text, smallint); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rewritenr(text, boolean, smallint, smallint, boolean, smallint, text, smallint) RETURNS text
    AS $_$
	DECLARE
		called ALIAS FOR $1;
		cutbool ALIAS FOR $2;
		digitnr ALIAS FOR $3;
		poscut ALIAS FOR $4;
		replacebool ALIAS FOR $5;
		posrpl ALIAS FOR $6;
		digitrplnr ALIAS FOR $8;
		digitrpl ALIAS FOR $7;
		front text;
		back text;
		result text;
	BEGIN

		result:=called;
		IF cutbool IS TRUE THEN
			result:=substr(result,1,poscut-1) || substr(result,poscut+digitnr,length(result)-poscut-digitnr+1);
		ELSEIF replacebool IS TRUE THEN
			IF digitrplnr IS NULL THEN
				RETURN digitrpl;
			END IF;
			result:=substr(result,1,posrpl-1) || digitrpl || substr(result,posrpl+digitrplnr,length(result)-posrpl-digitrplnr+1);
		END IF;
		RETURN result;
	END;
$_$
    LANGUAGE plpgsql;


ALTER FUNCTION public.rewritenr(text, boolean, smallint, smallint, boolean, smallint, text, smallint) OWNER TO postgres;

--
-- Name: updateaccounts(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION updateaccounts() RETURNS SETOF record
    AS $$
	DECLARE
		result record;
	BEGIN
		FOR result IN SELECT enabled ,protocol,username, description,interval,formats,authname ,password ,server ,
gatekeeper,domain,registrar,outbound ,localaddress, modified, account ,id, status, number,TRUE AS gw FROM accounts WHERE enabled IS TRUE AND modified IS TRUE LOOP
			RETURN next result;
		END LOOP;
		UPDATE accounts SET modified=false WHERE modified IS TRUE;
		RETURN;
	END;

$$
    LANGUAGE plpgsql;


ALTER FUNCTION public.updateaccounts() OWNER TO postgres;

SET default_tablespace = '';

SET default_with_oids = true;

--
-- Name: accounts; Type: TABLE; Schema: public; Owner: postgres; Tablespace:
--

CREATE TABLE accounts (
    enabled boolean,
    protocol text,
    username text,
    description text,
    "interval" text,
    formats text,
    authname text,
    "password" text,
    number text,
    server text,
    gatekeeper text,
    "domain" text,
    registrar text,
    outbound text,
    localaddress text,
    modified boolean,
    account text,
    id serial NOT NULL,
    status text
);


ALTER TABLE public.accounts OWNER TO postgres;

--
-- Name: accounts_id_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval(pg_catalog.pg_get_serial_sequence('accounts', 'id'), 1, false);


SET default_with_oids = false;

--
-- Name: cdr; Type: TABLE; Schema: public; Owner: postgres; Tablespace:
--

CREATE TABLE cdr (
    "time" timestamp without time zone,
    chan text,
    address text,
    direction text,
    billid text,
    caller text,
    "called" text,
    duration time without time zone,
    billtime time without time zone,
    ringtime time without time zone,
    status text,
    reason text,
    ended boolean
);


ALTER TABLE public.cdr OWNER TO postgres;

SET default_with_oids = true;

--
-- Name: form; Type: TABLE; Schema: public; Owner: postgres; Tablespace:
--

CREATE TABLE form (
    "location" text,
    "called" text,
    error text,
    line text
);


ALTER TABLE public.form OWNER TO postgres;

--
-- Name: lines; Type: TABLE; Schema: public; Owner: postgres; Tablespace:
--

CREATE TABLE lines (
    line text,
    "password" text,
    first_name text,
    last_name text,
    address text,
    inuse integer,
    "location" text,
    expires timestamp without time zone
);


ALTER TABLE public.lines OWNER TO postgres;

--
-- Name: messages; Type: TABLE; Schema: public; Owner: postgres; Tablespace:
--

CREATE TABLE messages (
    message text,
    date timestamp without time zone
);


ALTER TABLE public.messages OWNER TO postgres;

--
-- Name: routes; Type: TABLE; Schema: public; Owner: postgres; Tablespace:
--

CREATE TABLE routes (
    priority smallint,
    protocol text,
    prefix text,
    ip text,
    port text,
    iaxuser text,
    iaxcontext text,
    chan_group text,
    id serial NOT NULL,
    account text,
    cutbool boolean,
    nrdigcut smallint,
    poscut smallint,
    replacebool boolean,
    posrpl smallint,
    digrpl text,
    nrdigrpl smallint
);


ALTER TABLE public.routes OWNER TO postgres;

--
-- Name: routes_id_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval(pg_catalog.pg_get_serial_sequence('routes', 'id'), 24, true);


--
-- Name: users; Type: TABLE; Schema: public; Owner: postgres; Tablespace:
--

CREATE TABLE users (
    username text,
    "password" text,
    "first" text,
    "last" text,
    description text
);


ALTER TABLE public.users OWNER TO postgres;

--
-- Data for Name: accounts; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY accounts (enabled, protocol, username, description, "interval", formats, authname, "password", number, server, gatekeeper, "domain", registrar, outbound, localaddress, modified, account, id, status) FROM stdin;
\.


--
-- Data for Name: cdr; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY cdr ("time", chan, address, direction, billid, caller, "called", duration, billtime, ringtime, status, reason, ended) FROM stdin;
\.


--
-- Data for Name: form; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY form ("location", "called", error, line) FROM stdin;
none	\N	\N	\N
none	\N	\N	\N
none	\N	\N	\N
\.


--
-- Data for Name: lines; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY lines (line, "password", first_name, last_name, address, inuse, "location", expires) FROM stdin;
\.


--
-- Data for Name: messages; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY messages (message, date) FROM stdin;
\.


--
-- Data for Name: routes; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY routes (priority, protocol, prefix, ip, port, iaxuser, iaxcontext, chan_group, id, account, cutbool, nrdigcut, poscut, replacebool, posrpl, digrpl, nrdigrpl) FROM stdin;
\.


--
-- Data for Name: users; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY users (username, "password", "first", "last", description) FROM stdin;
admin	admin	admin	admin	admin
\.


--
-- Name: timeindex; Type: INDEX; Schema: public; Owner: postgres; Tablespace:
--

CREATE INDEX timeindex ON cdr USING btree ("time");


ALTER INDEX public.timeindex OWNER TO postgres;

--
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM postgres;
GRANT ALL ON SCHEMA public TO postgres;
GRANT ALL ON SCHEMA public TO PUBLIC;


--
-- PostgreSQL database dump complete
--

